%==========================================================================
%
%   getPointOnPath.m
%
%   Authors: SUMO Lab Team
%   Version: 1.0
%   Copyright: 2017
%   
%   When referring to ALBATROS please make reference to the corresponding publication:
%   
%   Van Steenkiste T., J. van der Herten, D. Deschrijver and T. Dhaene.
%   "ABLATROS: Adaptive Line-Based Sampling Trajectories for Sequential
%   Measurements". Engineering with Computers.
%
%==========================================================================
%
%   SIGNATURE:
%   point = getPointOnPath(part,path,pathDistances)
%
%==========================================================================
%
%   PURPOSE:
%   Determine the position of a point on the path after a percentage of the
%   distance
%
%   INPUT:
%   part: value between 0 and 1 indicating how much of the path has been
%   traversed
%   path: points determening the path on which to choose a point
%   pathDistances: distances between path points
%
%   OUTPUT:
%   point: point at a specific position on the path
%   %==========================================================================

function point = getPointOnPath(part,path,pathDistances)
	% part = [0,1];
	totalDistance = sum(pathDistances);
	part = part * totalDistance;
	traveledDistance = 0;
	k = 1;
	while (k<length(pathDistances))&&(traveledDistance + pathDistances(k) < part)
		traveledDistance = traveledDistance + pathDistances(k);
		k = k+1;
	end
	remaining = part - traveledDistance;
	point = takePointOnLine(remaining,path(k,:),path(k+1,:));
end