%==========================================================================
%
%   sortPointsClockwise.m
%
%   Authors: SUMO Lab Team
%   Version: 1.0
%   Copyright: 2017
%   
%   When referring to ALBATROS please make reference to the corresponding publication:
%   
%   Van Steenkiste T., J. van der Herten, D. Deschrijver and T. Dhaene.
%   "ABLATROS: Adaptive Line-Based Sampling Trajectories for Sequential
%   Measurements". Engineering with Computers.
%
%==========================================================================
%
%   SIGNATURE:
%   [ sortedPoints, indices ] = sortPointsClockwise( points )
%
%==========================================================================
%
%   PURPOSE:
%   Sort points in a clockwise fashion
%
%   INPUT:
%   points: points to sort
%  
%   OUTPUT:
%   sortedPoints: points in sorted order
%   indices: sorted indices of original points
%   %==========================================================================

function [ sortedPoints, indices ] = sortPointsClockwise( points )
    % only 2D or 3D coplaner points
    dimensionality = size(points,2);
    if dimensionality == 2
        meanX = mean(points(:,1));
        meanY = mean(points(:,2));
        angles = atan2(points(:,2) - meanY, points(:,1) - meanX);
        [~,indices] = sort(angles);
        sortedPoints = points(indices,:);
    else
       % 3D, points are assumed to be coplanar
       if length(unique(points(:,1))) == 1
            [ ~, indices ] = sortPointsClockwise( points(:,2:3) );
            sortedPoints = points(indices,:);
       else
           if size(points,1)< 3
               sortedPoints = points;
               indices = 1:size(points,1);
           else
               N = cross(points(2,:) - points(1,:),points(3,:) - points(1,:));
               O = points(1,:);
               Yaxis = cross([1 0 0],N);
               Xaxis = cross(Yaxis,N);
               points2D = (points-repmat(O,size(points,1),1))*[Xaxis/norm(Xaxis);Yaxis/norm(Yaxis)]';
               [ ~, indices ] = sortPointsClockwise( points2D );
               sortedPoints = points(indices,:);
           end
       end
    end
end

